@@ -15,10 +15,11 @@ class Term(BaseModel):
     identifier: str = Field(..., description="Unique identifier of the term", example="http://www.example.com/rocks")
     lexicon: str = Field(None, description="Lexicon of the term", example="MeSH")
     preferredForm: Optional[str] = Field(None, description="The preferred label of the term", example="rocks")
+    score: Optional[float] = Field(None, description="Confidence score of the term", example=0.87)
+    properties: Optional[Dict[str, Any]] = Field(None, description="Additional properties of the term",
+                                                 example={"altForms": ["basalt", "granite", "slate"],
+                                                          "wikidataId": "Q8063"})
 
-    # properties: Optional[Dict[str, Any]] = Field(None, description="Additional properties of the term",
-    #                                              example={"altForms": ["basalt", "granite", "slate"],
-    #                                                       "wikidataId": "Q8063"})
     def __eq__(self, other):
         return other and self.lexicon == other.lexicon and self.identifier == other.identifier
 
